import { Tag } from 'ant-design-vue'
import { BasicColumn, FormProps } from '@/components/Table'

export interface TypeOption {
    label: string
    value: string
    disabled?: boolean
}

/**
 * 支持的数据源类型
 */
export const typeOptions: TypeOption[] = [
    {
        label: '单表',
        value: 'Single',
    },
    {
        label: '主表',
        value: 'Master',
        disabled: true,
    },
    {
        label: '从表',
        value: 'Slave',
        disabled: true,
    },
]

// ================================
export function getColumns(): BasicColumn[] {
    return [
        {
            title: '表类型',
            dataIndex: 'type',
        },
        {
            title: '表名',
            dataIndex: 'name',
        },
        {
            title: '表描述',
            dataIndex: 'describe',
        },
        {
            title: '版本',
            dataIndex: 'version',
            sorter: true,
        },
        {
            title: '同步状态',
            dataIndex: 'sync',
            sorter: true,
            customRender: ({ value }) => <Tag color={value ? 'green' : 'red'}>{value ? '已同步' : '未同步'}</Tag>,
        },
        {
            title: '创建时间',
            dataIndex: 'createTime',
            sorter: true,
            width: 180,
        },
    ]
}
export function getDataSource() {
    return (() => {
        const data = []

        data.push({
            id: '1',
            type: '单表',
            name: 'bs_staff',
            describe: '人员信息表',
            version: '1',
            sync: true,
            createTime: '2023-02-26 15:36:01',
        })

        return data
    })()
}
export function getFormConfig(): Partial<FormProps> {
    return {
        layout: 'inline',
        name: 'query',
        colon: true,
        compact: true,
        schemas: [
            {
                field: `type`,
                label: `表类型`,
                component: 'Select',
                componentProps: {
                    options: typeOptions,
                    mode: 'multiple',
                    style: {
                        width: '180px',
                    },
                },
            },
            {
                field: `name`,
                label: `表名`,
                component: 'Input',
            },
            {
                field: `describe`,
                label: `表描述`,
                component: 'Input',
            },
        ],
        showAdvancedButton: false,
        submitButtonOptions: {
            preIcon: 'material-symbols:search',
        },
    }
}
